==> rc-ui-lib-0.1.58.tgz: package/lib/empty/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function React() {
  var data = _interopRequireWildcard(require("react"));

  React = function React() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _button = _interopRequireDefault(require("../../button"));

var _Network = require("../Network");

var _ = _interopRequireDefault(require(".."));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('Empty', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should render image correctly', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
      image: "search"
    }));
    expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();
  });
  it('should render description correctly', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
      description: "description"
    }));
    expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();
  });
  it('should render bottom correctly', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, null, /*#__PURE__*/React().createElement(_button.default, {
      round: true,
      type: "primary",
      className: "bottom-button"
    }, "\u6309\u94AE")));
    expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();
  });
  it('should render svg when image is network component', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
      image: _Network.Network
    }));
    expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();
  });
  it('should render svg when prop image is network', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
      image: "network"
    }));
    expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();
  });
  it('should change image size when using image-size prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    var image;
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              image: "search",
              imageSize: 50
            }));
            image = wrapper.find('.rc-empty__image');
            expect(image.getDOMNode().style.width).toEqual('50px');
            expect(image.getDOMNode().style.height).toEqual('50px');
            _context.next = 6;
            return wrapper.setProps({
              imageSize: '1vw'
            });

          case 6:
            expect(image.getDOMNode().style.width).toEqual('1vw');
            expect(image.getDOMNode().style.height).toEqual('1vw');

          case 8:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
});

==> rc-ui-lib-0.2.4.tgz: package/lib/empty/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function React() {
  var data = _interopRequireWildcard(require("react"));

  React = function React() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _button = _interopRequireDefault(require("../../button"));

var _Network = require("../Network");

var _ = _interopRequireDefault(require(".."));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('Empty', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should render image correctly', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
      image: "search"
    }));
    expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();
  });
  it('should render description correctly', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
      description: "description"
    }));
    expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();
  });
  it('should render bottom correctly', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, null, /*#__PURE__*/React().createElement(_button.default, {
      round: true,
      type: "primary",
      className: "bottom-button"
    }, "\u6309\u94AE")));
    expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();
  });
  it('should render svg when image is network component', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
      image: _Network.Network
    }));
    expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();
  });
  it('should render svg when prop image is network', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
      image: "network"
    }));
    expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();
  });
  it('should change image size when using image-size prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    var image;
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              image: "search",
              imageSize: 50
            }));
            image = wrapper.find('.rc-empty__image');
            expect(image.getDOMNode().style.width).toEqual('50px');
            expect(image.getDOMNode().style.height).toEqual('50px');
            _context.next = 6;
            return wrapper.setProps({
              imageSize: '1vw'
            });

          case 6:
            expect(image.getDOMNode().style.width).toEqual('1vw');
            expect(image.getDOMNode().style.height).toEqual('1vw');

          case 8:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
});
